@@ -4,7 +4,7 @@ __description__ = "One-stop solution for HTTP(S) testing."
 # import firstly for monkey patch if needed
 from mkrunner.ext.locust import main_locusts
 from mkrunner.parser import parse_parameters as Parameters
-from mkrunner.runner import HttpRunner
+from mkrunner.runner import mkrunner
 from mkrunner.testcase import Config, Step, RunRequest, RunTestCase
 
 
@@ -12,7 +12,7 @@ from mkrunner.testcase import Config, Step, RunRequest, RunTestCase
 __all__ = [
     "__version__",
     "__description__",
-    "HttpRunner",
+    "mkrunner",
     "Config",
     "Step",
     "RunRequest",
