@@ -36,7 +36,7 @@ from mkrunner.models import (
 )
 
 
-class HttpRunner(object):
+class mkrunner(object):
     config: Config
     teststeps: List[Step]
 
